@@ -1,5 +1,5 @@
 ######################################################################################################################
-# Copyright (C) 2017-2021 Spine project consortium
+# Copyright (C) 2017-2022 Spine project consortium
 # This file is part of Spine Database API.
 # Spine Database API is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser
 # General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your
@@ -139,7 +139,7 @@ class _ExecutionFilterState:
             scenarios = execution["scenarios"]
             timestamp = execution["timestamp"]
         except KeyError as e:
-            raise SpineDBAPIError(f"Key '{e}' not found in execution filter descriptor.")
+            raise SpineDBAPIError(f"Key '{e}' not found in execution filter descriptor.") from e
         if not isinstance(scenarios, list):
             raise SpineDBAPIError("Key 'scenarios' should contain a list.")
         return execution_item, scenarios, timestamp
