@@ -1,5 +1,5 @@
 ######################################################################################################################
-# Copyright (C) 2017-2021 Spine project consortium
+# Copyright (C) 2017-2022 Spine project consortium
 # This file is part of Spine Database API.
 # Spine Database API is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser
 # General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your
@@ -19,6 +19,7 @@ General helper functions and classes.
 import os
 import json
 import warnings
+from urllib.parse import urlparse, urlunparse
 from sqlalchemy import (
     Boolean,
     BigInteger,
@@ -941,31 +942,6 @@ def fix_name_ambiguity(input_list, offset=0, prefix=""):
     return result
 
 
-class ReceiveAllMixing:
-    """Provides _recvall, to read everything from a socket until the _EOT character is found."""
-
-    _ENCODING = "utf-8"
-    _BUFF_SIZE = 4096
-    _EOT = '\u0004'  # End of transmission
-    _BEOT = _EOT.encode(_ENCODING)
-    """End of message character"""
-
-    def _recvall(self):
-        """
-        Receives and returns all data in the request.
-
-        Returns:
-            str
-        """
-        fragments = []
-        while True:
-            chunk = self.request.recv(self._BUFF_SIZE)
-            fragments.append(chunk)
-            if chunk.endswith(self._BEOT):
-                break
-        return b"".join(fragments)[:-1]
-
-
 class CacheItem(dict):
     """A dictionary that behaves kinda like a row from a query result.
 
@@ -996,97 +972,16 @@ def vacuum(url):
     return freed, units[k]
 
 
-# Encode decode server messages
-_START_OF_TAIL = '\u001f'  # Unit separator
-_START_OF_ADDRESS = '\u0091'  # Private Use 1
-_ADDRESS_SEP = ':'
-
-
-class _TailJSONEncoder(json.JSONEncoder):
-    """
-    A custom JSON encoder that accummulates bytes objects into a tail.
-    The bytes object are encoded as a string pointing to the address in the tail.
-    """
-
-    def __init__(self):
-        super().__init__()
-        self._tail_parts = []
-        self._tip = 0
-
-    def default(self, o):
-        if isinstance(o, bytes):
-            self._tail_parts.append(o)
-            new_tip = self._tip + len(o)
-            fr, to = self._tip, new_tip - 1
-            address = f"{_START_OF_ADDRESS}{fr}{_ADDRESS_SEP}{to}"
-            self._tip = new_tip
-            return address
-        if isinstance(o, set):
-            return list(o)
-        if isinstance(o, SpineDBAPIError):
-            return str(o)
-        return super().default(o)
-
-    @property
-    def tail(self):
-        return b"".join(self._tail_parts)
-
-
-def encode(o):
-    """
-    Encodes given object (representing a server response) into a message with the following structure:
-
-        body | start of tail character | tail
-
-    The body is obtained by JSON-encoding the argument, while replacing all `bytes` objects by addresses in the tail.
-    The tail is computed by concatenating all `bytes` objects in the argument.
-    See class:`_TailJSONEncoder`.
+def remove_credentials_from_url(url):
+    """Removes username and password information from URLs.
 
     Args:
-        o (any): A Python object representing a server response.
+        url (str): URL
 
     Returns:
-        bytes: A message to the client.
+        str: sanitized URL
     """
-    encoder = _TailJSONEncoder()
-    s = encoder.encode(o)
-    return s.encode() + _START_OF_TAIL.encode() + encoder.tail
-
-
-def decode(b):
-    """
-    Decodes given message (representing a client request) into a Python object.
-    The message must have the following structure:
-
-        body | start of tail character | tail
-
-    The result is obtained by JSON-decoding the body, and then replacing all the addresses with the referred `bytes`
-    from the tail.
-
-    Args:
-        b (bytes): A message from the client.
-
-    Returns:
-        any: A Python object representing a client request.
-    """
-    body, tail = b.split(_START_OF_TAIL.encode())
-    o = json.loads(body)
-    return _expand_addresses_in_place(o, tail)
-
-
-def _expand_addresses_in_place(o, tail):
-    if isinstance(o, dict):
-        for k, v in o.items():
-            o[k] = _expand_addresses_in_place(v, tail)
-        return o
-    if isinstance(o, list):
-        for k, e in enumerate(o):
-            o[k] = _expand_addresses_in_place(e, tail)
-        return o
-    if isinstance(o, str):
-        if not o.startswith(_START_OF_ADDRESS):
-            return o
-        address = o.lstrip(_START_OF_ADDRESS)
-        fr, to = (int(x) for x in address.split(_ADDRESS_SEP))
-        return tail[fr : to + 1]
-    return o
+    parsed = urlparse(url)
+    if parsed.username is None:
+        return url
+    return urlunparse(parsed._replace(netloc=parsed.netloc.partition("@")[-1]))
