@@ -1,5 +1,5 @@
 ######################################################################################################################
-# Copyright (C) 2017-2021 Spine project consortium
+# Copyright (C) 2017-2022 Spine project consortium
 # This file is part of Spine Database API.
 # Spine Database API is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser
 # General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your
@@ -33,8 +33,30 @@ from ..parameter_value import (
 from ..exception import ParameterValueFormatError
 
 
+_NO_VALUE = object()
+
+
+def identity(x):
+    """Returns argument unchanged.
+
+    Args:
+        x (Any): value to return
+
+    Returns:
+        Any: x
+    """
+    return x
+
+
 def get_mapped_data(
-    data_source, mappings, data_header=None, table_name="", column_convert_fns=None, row_convert_fns=None
+    data_source,
+    mappings,
+    data_header=None,
+    table_name="",
+    column_convert_fns=None,
+    default_column_convert_fn=None,
+    row_convert_fns=None,
+    unparse_value=identity,
 ):
     """
     Args:
@@ -43,7 +65,9 @@ def get_mapped_data(
         data_header (list, optional): table header
         table_name (str, optional): table name
         column_convert_fns (dict(int,function), optional): mapping from column number to convert function
+        default_column_convert_fn (Callable, optional): default convert function for surplus columns
         row_convert_fns (dict(int,function), optional): mapping from row number to convert function
+        unparse_value (Callable): a callable that converts values to database format
 
     Returns:
         dict: Mapped data, ready for ``import_data()``
@@ -55,16 +79,17 @@ def get_mapped_data(
             mappings[k] = import_mapping_from_dict(mapping)
         elif not isinstance(mapping, ImportMapping):
             raise TypeError(f"mapping must be a dict or ImportMapping subclass, instead got: {type(mapping).__name__}")
-    if column_convert_fns is None:
-        column_convert_fns = {}
-    default_column_convert_fn = column_convert_fns[max(column_convert_fns)] if column_convert_fns else lambda x: x
-    if row_convert_fns is None:
-        row_convert_fns = {}
     mapped_data = {}
     errors = []
     rows = list(data_source)
     if not rows:
         return mapped_data, errors
+    if column_convert_fns is None:
+        column_convert_fns = {}
+    if row_convert_fns is None:
+        row_convert_fns = {}
+    if default_column_convert_fn is None:
+        default_column_convert_fn = column_convert_fns[max(column_convert_fns)] if column_convert_fns else identity
     for mapping in mappings:
         read_state = {}
         mapping = deepcopy(mapping)
@@ -135,7 +160,7 @@ def get_mapped_data(
                 full_row.append(row[column_pos])
                 mapping.import_row(full_row, read_state, mapped_data)
     _make_relationship_classes(mapped_data)
-    _make_parameter_values(mapped_data)
+    _make_parameter_values(mapped_data, unparse_value)
     return mapped_data, errors
 
 
@@ -246,7 +271,7 @@ def _make_relationship_classes(mapped_data):
     mapped_data["relationship_classes"] = full_rows
 
 
-def _make_parameter_values(mapped_data):
+def _make_parameter_values(mapped_data, unparse_value):
     value_pos = 3
     for key in ("object_parameter_values", "relationship_parameter_values"):
         rows = mapped_data.get(key)
@@ -254,7 +279,10 @@ def _make_parameter_values(mapped_data):
             continue
         valued_rows = []
         for row in rows:
-            value = _make_values(row, value_pos)
+            raw_value = _make_value(row, value_pos)
+            if raw_value is _NO_VALUE:
+                continue
+            value = unparse_value(raw_value)
             if value is not None:
                 row[value_pos] = value
                 valued_rows.append(row)
@@ -267,7 +295,7 @@ def _make_parameter_values(mapped_data):
         full_rows = []
         for entity_definition, extras in rows.items():
             if extras:
-                value = _make_values(extras, value_pos)
+                value = unparse_value(_make_value(extras, value_pos))
                 if value is not None:
                     extras[value_pos] = value
                     full_rows.append(entity_definition + tuple(extras))
@@ -276,16 +304,16 @@ def _make_parameter_values(mapped_data):
         mapped_data[key] = full_rows
 
 
-def _make_values(row, value_pos):
+def _make_value(row, value_pos):
     try:
         value = row[value_pos]
     except IndexError:
         return None
     if isinstance(value, dict):
         if "data" not in value:
-            return None
+            return _NO_VALUE
         return _parameter_value_from_dict(value)
-    elif isinstance(value, str):
+    if isinstance(value, str):
         try:
             return from_database(*split_value_and_type(value))
         except ParameterValueFormatError:
