@@ -1,5 +1,5 @@
 ######################################################################################################################
-# Copyright (C) 2017-2021 Spine project consortium
+# Copyright (C) 2017-2022 Spine project consortium
 # This file is part of Spine Database API.
 # Spine Database API is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser
 # General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your
@@ -43,7 +43,7 @@ from .exception import ParameterValueFormatError
 
 # Defaulting to seconds precision in numpy.
 _NUMPY_DATETIME_DTYPE = "datetime64[s]"
-_NUMPY_DATETIME64_UNIT = "s"
+NUMPY_DATETIME64_UNIT = "s"
 # Default start time guess, actual value not currently given in the JSON specification.
 _TIME_SERIES_DEFAULT_START = "0001-01-01T00:00:00"
 # Default resolution if it is omitted from the index entry.
@@ -342,7 +342,7 @@ def _duration_from_database(value):
         # Set default unit to minutes if value is a plain number.
         if not isinstance(value, str):
             value = f"{value}m"
-    elif isinstance(value, Sequence):  # It is a deprecate list of durations.
+    elif isinstance(value, Sequence):
         # This type of 'variable duration' is deprecated. We make an Array instead.
         # Set default unit to minutes for plain numbers in value.
         value = [v if isinstance(v, str) else f"{v}m" for v in value]
@@ -403,7 +403,7 @@ def _time_series_from_dictionary(value_dict):
     values = np.empty(len(data))
     for index, (stamp, series_value) in enumerate(data.items()):
         try:
-            stamp = np.datetime64(stamp, _NUMPY_DATETIME64_UNIT)
+            stamp = np.datetime64(stamp, NUMPY_DATETIME64_UNIT)
         except ValueError:
             raise ParameterValueFormatError(f'Could not decode time stamp "{stamp}"')
         stamps.append(stamp)
@@ -479,7 +479,7 @@ def _time_series_from_two_columns(value_dict):
         if not isinstance(element, Sequence) or len(element) != 2:
             raise ParameterValueFormatError("Invalid value in time series array")
         try:
-            stamp = np.datetime64(element[0], _NUMPY_DATETIME64_UNIT)
+            stamp = np.datetime64(element[0], NUMPY_DATETIME64_UNIT)
         except ValueError:
             raise ParameterValueFormatError(f'Could not decode time stamp "{element[0]}"')
         stamps.append(stamp)
@@ -590,7 +590,9 @@ def _map_values_from_database(values_in_db):
     values = list()
     for value_in_db in values_in_db:
         value = from_dict(value_in_db) if isinstance(value_in_db, dict) else value_in_db
-        if value is not None and not isinstance(value, (float, bool, Duration, IndexedValue, str, DateTime)):
+        if isinstance(value, int):
+            value = float(value)
+        elif value is not None and not isinstance(value, (float, bool, Duration, IndexedValue, str, DateTime)):
             raise ParameterValueFormatError(f'Unsupported value type for Map: "{type(value).__name__}".')
         values.append(value)
     return values
@@ -1275,10 +1277,10 @@ class TimeSeriesVariableResolution(TimeSeries):
             date_times = np.empty(len(indexes), dtype=_NUMPY_DATETIME_DTYPE)
             for i, index in enumerate(indexes):
                 if isinstance(index, DateTime):
-                    date_times[i] = np.datetime64(index.value, _NUMPY_DATETIME64_UNIT)
+                    date_times[i] = np.datetime64(index.value, NUMPY_DATETIME64_UNIT)
                 else:
                     try:
-                        date_times[i] = np.datetime64(index, _NUMPY_DATETIME64_UNIT)
+                        date_times[i] = np.datetime64(index, NUMPY_DATETIME64_UNIT)
                     except ValueError:
                         raise ParameterValueFormatError(
                             f'Cannot convert "{index}" of type {type(index).__name__} to time stamp.'
