@@ -1,5 +1,5 @@
 ######################################################################################################################
-# Copyright (C) 2017-2021 Spine project consortium
+# Copyright (C) 2017-2022 Spine project consortium
 # This file is part of Spine Database API.
 # Spine Database API is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser
 # General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your
@@ -160,7 +160,7 @@ def get_mapped_data_from_xlsx(filepath):
     }
     table_types = table_row_types = dict.fromkeys(mapping["selected_tables"], {})
     mapped_data, errors = connector.get_mapped_data(
-        table_mappings, table_options, table_types, table_row_types, max_rows=-1
+        table_mappings, table_options, table_types, {}, table_row_types, max_rows=-1
     )
     connector.disconnect()
     return mapped_data, errors
